@@ -27,7 +27,7 @@
 }
 
 # Note the PSF and calcregion must already be finesampled here. imgdim should not be.
-.profitSetupDataBenchmark <- function(modellist, calcregion, imgdim,
+profitDataBenchmark <- function(modellist, calcregion, imgdim,
   finesample=1L, psf=NULL, fitpsf=FALSE, omp_threads=NULL, openclenv=NULL,
   openclenv_int=openclenv, openclenv_conv=openclenv,
   nbenchmark=0L, nbenchint=nbenchmark, nbenchconv=nbenchmark,
@@ -120,10 +120,30 @@
         openclenv=openclenv_conv)
     }
   }
-  rv = list(benches=benches, convopt=convopt, usecalcregion=usecalcregion)
+  rv = list(
+    benches=benches, convopt=convopt, usecalcregion=usecalcregion,
+    openclenv = openclenv_int)
+  class(rv)="profit.data.benchmark"
   return(rv)
 }
 
+profitDataSetOptionsFromBenchmarks <- function(Data, benchmarks)
+{
+  if(class(Data) != 'profit.data')
+  {
+    stop("The Data must be of class profit.data, as generated by the profitSetupData function!")
+  }
+  if(class(benchmarks) != 'profit.data.benchmark')
+  {
+    stop("The benchmarks must be of class profit.data.benchmark, as generated by the profitSetupData function!")
+  }
+  for(var in names(benchmarks))
+  {
+    Data[[var]] = benchmarks[[var]]
+  }
+  return(Data)
+}
+
 profitSetupData=function(image, region, sigma, segim, mask, modellist,
   tofit, tolog, priors, intervals, constraints, psf=NULL, psfdim=dim(psf),
   finesample=1L, psffinesampled=FALSE, magzero=0, algo.func='LA',
@@ -267,14 +287,14 @@ profitSetupData=function(image, region, sigma, segim, mask, modellist,
   # Note this actually stores whether we are fitting the PSF image for convolution with extended sources
   # It should probably be renamed fitpsfimg but will remain as such for backwards compatibility for now
   fitpsf = psftype == "analytical" && any(unlist(tofit$psf)) && any(!(names(modellist) %in% c("psf","pointsource","sky")))
-  benchmarks = .profitSetupDataBenchmark(modellist=modellist, calcregion=calcregion, imgdim=imagedim,
-    finesample=finesample, psf=psf, fitpsf=fitpsf, omp_threads=omp_threads,
-    openclenv=openclenv, openclenv_int=openclenv_int, openclenv_conv=openclenv_conv,
-    nbenchmark=nbenchmark, nbenchint=nbenchint, nbenchconv=nbenchint,
-    benchintmethods=benchintmethods, benchconvmethods = benchconvmethods,
-    benchprecisions=benchprecisions, benchconvprecisions=benchconvprecisions,
-    benchintprecisions=benchintprecisions, benchopenclenvs = benchopenclenvs,
-    printbenchmark=printbenchmark, printbenchint=printbenchint, printbenchconv=printbenchconv)
+  benchmarks = profitDataBenchmark(modellist = modellist, calcregion = calcregion, imgdim = imagedim,
+    finesample = finesample, psf=psf, fitpsf = fitpsf, omp_threads = omp_threads,
+    openclenv = openclenv, openclenv_int = openclenv_int, openclenv_conv = openclenv_conv,
+    nbenchmark = nbenchmark, nbenchint = nbenchint, nbenchconv = nbenchint,
+    benchintmethods = benchintmethods, benchconvmethods = benchconvmethods,
+    benchprecisions = benchprecisions, benchconvprecisions = benchconvprecisions,
+    benchintprecisions = benchintprecisions, benchopenclenvs = benchopenclenvs,
+    printbenchmark = printbenchmark, printbenchint=printbenchint, printbenchconv=printbenchconv)
   
   init = unlist(modellist)
   init[unlist(tolog)]=log10(init[unlist(tolog)])
@@ -283,13 +303,14 @@ profitSetupData=function(image, region, sigma, segim, mask, modellist,
   parm.names=names(init)
   mon.names=c("LL","LP","time")
   if(profitParseLikefunc(like.func) == "t") mon.names=c(mon.names,"dof")
-  profit.data=list(init=init, image=image, mask=mask, sigma=sigma, segim=segim, modellist=modellist,
-                   psf=psf, psftype=psftype, fitpsf=fitpsf,
-                   algo.func=algo.func, mon.names=mon.names, parm.names=parm.names, N=length(which(as.logical(region))),
-                   region=region, calcregion=calcregion, usecalcregion=benchmarks$usecalcregion, convopt=benchmarks$convopt,
-                   tofit=tofit, tolog=tolog, priors=priors, intervals=intervals, constraints=constraints,
-                   like.func = like.func, magzero=magzero, finesample=finesample, imagedim=imagedim, verbose=verbose, magmu=magmu,
-                   openclenv=openclenv_int, omp_threads=omp_threads, benches=benchmarks$benches)
+  profit.data=list(
+    init=init, image=image, mask=mask, sigma=sigma, segim=segim, modellist=modellist,
+    psf=psf, psftype=psftype, fitpsf=fitpsf,
+    algo.func=algo.func, mon.names=mon.names, parm.names=parm.names, N=length(which(as.logical(region))),
+    region=region, calcregion=calcregion, tofit=tofit, tolog=tolog, priors=priors, intervals=intervals, constraints=constraints,
+    like.func = like.func, magzero=magzero, finesample=finesample, imagedim=imagedim, verbose=verbose, magmu=magmu,
+    openclenv=openclenv, omp_threads=omp_threads)
   class(profit.data)="profit.data"
+  profit.data = profitDataSetOptionsFromBenchmarks(profit.data, benchmarks)
   return=profit.data
 }
\ No newline at end of file
